import json
from typing import Tuple

from requests import Response, Session
from requests.exceptions import HTTPError

from .config_helper import ConfigHelper


class AlarmsHelper:
    def __init__(self, session: Session):
        self.session = session

    def get_alarms(self, id: str) -> Tuple[dict, Response]:
        """Get all alarms"""

        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/alarms/{id}")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Alarms", r)

        return content, r

    def post_alarm(
        self,
        message: str,
        rule_id: int,
        status: str,
        state: str,
        state_date: str,
        state_message: str,
    ) -> Tuple[dict, Response]:
        """Post an alarm"""
        content = {
            "messageJSON": message,
            "ruleId": rule_id,
            "notificationStatus": status,
            "state": state,
            "stateDate": state_date,
            "stateMessage": state_message,
        }

        try:
            r = self.session.post(f"{ConfigHelper.host}/alarms", json=content)
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Post alarm", r)

        return content, r

    def put_alarm(
        self,
        id: int,
        state: str,
        state_message: str,
        status: str,
    ) -> Tuple[dict, Response]:
        """Put an alarm"""

        content = {
            "state": state,
            "stateMessage": state_message,
            "notificationStatus": status,
        }

        try:
            r = self.session.put(f"{ConfigHelper.host}/alarms/{id}", json=content)
            r.raise_for_status()
        except HTTPError as e:
            pass
        finally:
            ConfigHelper.show_status("    Put alarm", r)

        return {}, r

    def delete_alarm(self, id: int) -> Tuple[dict, Response]:
        """Delete an alarm"""

        try:
            r = self.session.delete(f"{ConfigHelper.host}/alarms/{id}")
            r.raise_for_status()
        except HTTPError as e:
            pass
        finally:
            ConfigHelper.show_status("    Delete Alarm", r)

        return {}, r



from typing import Tuple
import json
from requests import Response, Session
from requests.exceptions import HTTPError

from .config_helper import ConfigHelper


class ResponseHelper:
    def __init__(self, session: Session):
        self.session = session

    def get_responses(self) -> Tuple[dict, Response]:
        """Get all responses of the user for today."""
        content = {}
        try:
            r = self.session.get(f"{ConfigHelper.host}/oneshot/responses")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Responses", r)

        return content, r

    def get_all_responses(self, since: str, to: str) -> Tuple[dict, Response]:
        """Get all responses of the user for a specific period of time."""

        content = {}

        try:
            r = self.session.get(
                f"{ConfigHelper.host}/oneshot/allresponses/since/{since}/to/{to}"
            )
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get All Responses", r)

        return content, r

    def get_factor_responses(self, theme: int, factor: int) -> Tuple[dict, Response]:
        """Get the responses of the user for today to this factor and for the given period."""

        content = {}

        try:
            r = self.session.get(
                f"{ConfigHelper.host}/themes/{theme}/factors/{factor}/responses"
            )
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Factor Responses", r)

        return content, r

    def put_response(
        self, theme: int, factor: int, value: int, date: str
    ) -> Tuple[dict, Response]:
        """Insert the current response of the user for this factor. Key on the columns (userId, factorId, date, period). If date is not specified, it is set to today."""
        content = {
            "responseOptionId": value,
            "roomId": None,
            "period": "day",
            "date": date,
        }

        try:
            r = self.session.put(
                f"{ConfigHelper.host}/themes/{theme}/factors/{factor}/responses",
                json=content,
            )
        except HTTPError as e:
            pass
        finally:
            ConfigHelper.show_status("    Put Response", r)

        return content, r

    def delete_response(
        self, theme: int, factor: int, response: int
    ) -> Tuple[dict, Response]:
        """Delete the given response."""

        try:
            r = self.session.delete(
                f"{ConfigHelper.host}/themes/{theme}/factors/{factor}/responses/{response}"
            )
            r.raise_for_status()
        except HTTPError as e:
            pass
        finally:
            ConfigHelper.show_status("    Delete Response", r)

        return {}, r

    def get_all_themes_responses(self) -> Tuple[dict, Response]:
        """Get responses of today to all themes for the user."""

        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/themes/responses")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get All Themes Responses", r)

        return content, r

    def get_theme_responses(self, theme: int) -> Tuple[dict, Response]:
        """Get todays response of the user for given theme (only used for the environment category question)."""

        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/themes/{theme}/responses")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get All Themes Responses", r)

        return content, r

    def put_theme_response(
        self, theme: int, factor: int, response_option: int, room: int, period: str
    ) -> Tuple[dict, Response]:
        """Update the crrent response of the user. Key on the columns (userId, themeId, period, date)."""

        content = {
            "factorId": factor,
            "responseOptionId": response_option,
            "roomId": room,
            "period": period,
        }

        try:
            r = self.session.put(
                f"{ConfigHelper.host}/themes/{theme}/responses", json=content
            )
            r.raise_for_status()
        except HTTPError as e:
            pass
        finally:
            ConfigHelper.show_status("    Put Theme Response", r)

        return content, r



from datetime import date, timedelta
import pprint

from .config_helper import ConfigHelper
from .soozaccess import SoozAccess

# root
# yt0QlYIQXS7xH6KDyn4M8Vcq


def daterange(start_date: date, n_dates: int):
    for n in range(n_dates):
        yield start_date + timedelta(n)


def main():
    users = ["test1", "test2"]
    group = "group test"
    start_date = date(2020, 1, 1)
    n_dates = 5

    ConfigHelper.host = "http://localhost:3000"
    ConfigHelper.verbose = True

    SoozAccess.prepare_users(group, users)

    # create data
    for name in users:
        with SoozAccess(name, name) as user:
            for day in daterange(start_date, n_dates):
                user.responses.put_response(2, 21, 3, day.strftime("%Y-%m-%d"))


if __name__ == "__main__":
    main()



from .__main__ import daterange

from .logger import Logger
from .soozaccess import SoozAccess
from .config_helper import ConfigHelper
from .enterprise_helper import EnterpriseHelper
from .factor_helper import FactorHelper
from .group_helper import GroupHelper
from .group_member_helper import GroupMemberHelper
from .level_helper import LevelHelper
from .logger import Logger
from .response_helper import ResponseHelper
from .response_option_helper import ResponseOptionHelper
from .statistics_helper import StatisticsHelper
from .theme_helper import ThemeHelper
from .user_helper import UserHelper

__all__ = [
    "SoozAccess",
    "daterange",
    "Logger",
    "ConfigHelper",
    "EnterpriseHelper",
    "FactorHelper",
    "GroupHelper",
    "GroupMemberHelper",
    "LevelHelper",
    "Logger",
    "ResponseHelper",
    "ResponseOptionHelper",
    "StatisticsHelper",
    "ThemeHelper",
    "UserHelper",
]



import json
from typing import Tuple

from requests import Response, Session
from requests.exceptions import HTTPError

from .config_helper import ConfigHelper


class ThemeHelper:
    def __init__(self, session: Session):
        self.session = session

    def get_themes(self) -> Tuple[dict, Response]:
        """Get all themes (not specific to an enterprise)."""
        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/themes")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Themes", r)

        return content, r

    def get_theme(self, theme: int) -> Tuple[dict, Response]:
        """Get a specific theme."""

        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/themes/{theme}")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Theme", r)

        return content, r



import json
from typing import Tuple

from requests import Response, Session
from requests.exceptions import HTTPError

from .config_helper import ConfigHelper


class StatisticsHelper:
    def __init__(self, session: Session):
        self.session = session

    def get_stats_lastvote(self):
        """Returns last vote."""

        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/stats/lastVote")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Last Vote", r)

        return content, r

    def get_stats_response_count_for_factor(
        self,
        factor: int,
        start_date: str,
        end_date: str,
        room_id: int = None,
        group: int or list[int] = None,
    ) -> Tuple[dict, Response]:
        """Returns the number of responses per responseId for one factor."""

        content = {}
        params = {
            "factorId": factor,
            "dateFrom": start_date,
            "dateTo": end_date,
        }
        if room_id:
            params["roomId"] = room_id
        if group:
            params["groupId"] = group

        try:
            r = self.session.get(
                f"{ConfigHelper.host}/stats/responseCountForFactor", params=params
            )
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Count For Factor", r)

        return content, r

    def get_stats_days(
        self,
        factor: int,
        start_date: str,
        end_date: str,
        period: bool,
        room_id: int = None,
        group: int or list[int] = None,
    ) -> Tuple[dict, Response]:
        """Returns statistics by day (and by period or not)."""

        content = {}
        params = {
            "factorId": factor,
            "dateFrom": start_date,
            "dateTo": end_date,
            "period": period,
        }
        if room_id:
            params["roomId"] = room_id
        if group:
            params["groupId"] = group

        try:
            r = self.session.get(f"{ConfigHelper.host}/stats/days", params=params)
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Days", r)

        return content, r

    def get_stats_months(
        self,
        factor: int,
        start_date: str,
        end_date: str,
        room_id: int = None,
        group: int or list[int] = None,
    ) -> Tuple[dict, Response]:
        """Returns statsitics by month (and by period)."""

        content = {}
        params = {
            "factorId": factor,
            "dateFrom": start_date,
            "dateTo": end_date,
        }
        if room_id:
            params["roomId"] = room_id
        if group:
            params["groupId"] = group

        try:
            r = self.session.get(f"{ConfigHelper.host}/stats/months", params=params)
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Months", r)

        return content, r

    def get_stats_season(
        self,
        factor: int,
        start_date: str,
        end_date: str,
        room_id: int = None,
        group: int or list[int] = None,
    ) -> Tuple[dict, Response]:
        """Returns statistics by season."""

        content = {}
        params = {
            "factorId": factor,
            "dateFrom": start_date,
            "dateTo": end_date,
        }
        if room_id:
            params["roomId"] = room_id
        if group:
            params["groupId"] = group

        try:
            r = self.session.get(f"{ConfigHelper.host}/stats/seasons", params=params)
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Seasons", r)

        return content, r

    def get_stats_themes_by_votes(
        self,
        start_date: str,
        end_date: str,
        room_id: int = None,
        group: int or list[int] = None,
    ) -> Tuple[dict, Response]:
        """Returns the themes ordered by the number of votes (descending)."""

        content = {}
        params = {
            "dateFrom": start_date,
            "dateTo": end_date,
        }
        if room_id:
            params["roomId"] = room_id
        if group:
            params["groupId"] = group

        try:
            r = self.session.get(
                f"{ConfigHelper.host}/stats/sortedByNbVotes", params=params
            )
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Seasons", r)

        return content, r

    def get_stats_themes_by_feeling(
        self,
        start_date: str,
        end_date: str,
        room_id: int = None,
        group: int or list[int] = None,
    ) -> Tuple[dict, Response]:
        """Returns themes ordered by the average of the resonses (i.e. satisfaction)."""

        content = {}
        params = {
            "dateFrom": start_date,
            "dateTo": end_date,
        }
        if room_id:
            params["roomId"] = room_id
        if group:
            params["groupId"] = group

        try:
            r = self.session.get(
                f"{ConfigHelper.host}/stats/sortedByFeeling", params=params
            )
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Seasons", r)

        return content, r



from typing import Tuple
import json
from requests import Response, Session
from requests.exceptions import HTTPError

from .config_helper import ConfigHelper


class GroupMemberHelper:
    def __init__(self, session: Session):
        self.session = session

    def get_invitable_users(self, group: int) -> Tuple[dict, Response]:
        """Return users that can be invited to a group."""

        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/groups/{group}/invitableUsers")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Invitable Users", r)

        return content, r

    def post_group_invite(self, group: int, ids: list[int]) -> Tuple[dict, Response]:
        """Invite users to a specific group."""
        content = {"userIds": ids}

        try:
            r = self.session.post(
                f"{ConfigHelper.host}/groups/{group}/invite", json=content
            )
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Invite to Group", r)

        return content, r

    def put_group_invitation(
        self, group: int, status: str = "accepted"
    ) -> Tuple[dict, Response]:
        """Accept/decline an invitation to join a group."""

        content = {"status": status}

        try:
            r = self.session.put(
                f"{ConfigHelper.host}/groups/{group}/invitation",
                json=content,
            )
            r.raise_for_status()
        except HTTPError as e:
            pass
        finally:
            ConfigHelper.show_status("    Accept Group Invitation", r)

        return {}, r

    def get_group_members(self, id: int) -> Tuple[dict, Response]:
        """Return members of a group."""
        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/groups/{id}/members")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Groups Members", r)

        return content, r

    def delete_group_member(self, group: int, user: int) -> Tuple[dict, Response]:
        """Remove a user from a group."""

        content = {}

        try:
            r = self.session.delete(
                f"{ConfigHelper.host}/groups/{group}/members/{user}"
            )
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Groups", r)

        return content, r



from typing import Tuple
import json
from requests import Response, Session
from requests.exceptions import HTTPError

from .config_helper import ConfigHelper
from .logger import Logger


class GroupHelper:
    def __init__(self, session: Session):
        self.session = session

    def get_user_groups(self) -> Tuple[dict, Response]:
        """Returns all groups of a user."""
        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/groups")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Groups", r)

        return content, r

    def post_group(self, name: str, description: str) -> Tuple[dict, Response]:
        """Create a group in the enterprise of the user."""
        if name in [g["group"]["name"] for g in self.get_user_groups()[0]]:
            Logger.write("Group already exists")
            return None, None

        content = {"name": name, "description": description}

        try:
            r = self.session.post(f"{ConfigHelper.host}/groups", json=content)
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Insert Group", r)

        return content, r

    def put_group(
        self, group: int, name: str, description: str
    ) -> Tuple[dict, Response]:
        """Update a group (requires the user to be admin of the group)."""

        content = {
            "name": name,
            "description": description,
        }

        try:
            r = self.session.put(f"{ConfigHelper.host}/groups/{group}", json=content)
            r.raise_for_status()
        except HTTPError as e:
            pass
        finally:
            ConfigHelper.show_status("    Put Group", r)

        return {}, r

    def delete_group(self, group: int) -> Tuple[dict, Response]:
        """Delete a group (requires the user to be admin of the group)."""
        if group not in [g["group"]["id"] for g in self.get_user_groups()[0]]:
            Logger.write("Group does not exist")
            return None

        try:
            r = self.session.delete(f"{ConfigHelper.host}/groups/{group}")
            r.raise_for_status()
        except HTTPError as e:
            pass
        finally:
            ConfigHelper.show_status("    Remove Group", r)

        return {}, r

    def remove_groups(self):
        for g in self.get_user_groups()[0]:
            self.delete_group(g["group"]["id"])



from requests import Response
from .logger import Logger


class ConfigHelper:
    """Static class to store configuration and status display config"""

    host = ""
    verbose = None

    @classmethod
    def show_status(self, text: str, r: Response):
        reason = r.reason if r.status_code == 200 else r.content.decode("ascii")

        Logger.write(f"[{'API':5s}] {text:30s} [{r.status_code}] {reason}")



import json
from typing import Tuple

from requests import Response, Session
from requests.exceptions import HTTPError

from .config_helper import ConfigHelper


class UserHelper:
    def __init__(self, session: Session, name: str, token: str):
        self.session = session
        self.name = name
        self.token = token
        self.user_id = None

    def post_user(self, entreprise_id: int = 1) -> Tuple[dict, Response]:
        """Create a user."""
        content = {
            "firstName": self.name,
            "lastName": self.name,
            "sex": "m",
            "username": self.name,
            "email": f"{self.name}@test",
            "enterpriseId": entreprise_id,
            "token": self.token,
            "activatePopup": True,
            "points": 0,
        }
        try:
            r = self.session.post(f"{ConfigHelper.host}/users", json=content)
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Create User", r)

        return content, r

    def put_user(
        self,
        first_name: str,
        last_name: str,
        sex: str,
        username: str,
        email: str,
        enterprise: int,
        old_token: str,
        token: str,
    ) -> Tuple[dict, Response]:
        """Update the connected user."""
        content = {
            "firstName": first_name,
            "lastName": last_name,
            "sex": sex,
            "username": username,
            "email": email,
            "enterpriseId": enterprise,
            "oldToken": old_token,
            "token": token,
            "activatePopup": True,
        }

        try:
            r = self.session.put(f"{ConfigHelper.host}/users", json=content)
            r.raise_for_status()
        except HTTPError as e:
            pass
        finally:
            ConfigHelper.show_status("    Put User", r)

        return {}, r

    def login(self) -> Tuple[dict, Response]:
        """Login a user."""
        content = {"user": {"identifier": self.name, "token": self.token}}

        try:
            r = self.session.post(f"{ConfigHelper.host}/users/login", json=content)
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
            self.user_id = content["id"]
        finally:
            ConfigHelper.show_status(f"*{self.name}* Login", r)

        return content, r

    def logout(self) -> Tuple[dict, Response]:
        """Logout the connected user."""
        try:
            r = self.session.post(f"{ConfigHelper.host}/users/logout")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            self.user_id = None
        finally:
            ConfigHelper.show_status(f"*{self.name}* Logout", r)

        return {}, r



import json
from typing import Tuple

import requests

from .alarms_helper import AlarmsHelper
from .config_helper import ConfigHelper
from .enterprise_helper import EnterpriseHelper
from .factor_helper import FactorHelper
from .group_helper import GroupHelper
from .group_member_helper import GroupMemberHelper
from .level_helper import LevelHelper
from .logger import Logger
from .response_helper import ResponseHelper
from .response_option_helper import ResponseOptionHelper
from .rules_helper import RulesHelper
from .statistics_helper import StatisticsHelper
from .theme_helper import ThemeHelper
from .user_helper import UserHelper


class SoozAccess(object):
    def __init__(self, name: str, token: str, force_create: bool = True):
        if ConfigHelper.host == "":
            raise ValueError(
                "Please provide a host before instanciating with 'ConfigHelper.host=\"http://<host>\"'"
            )
        if ConfigHelper.verbose == None:
            raise ValueError(
                "Please provide a boolean value to 'verbose' attribute before instanciating with ''ConfigHelper.verbose = <bool>'"
            )

        self.force_create = force_create
        self.session = requests.session()

        self.alarms = AlarmsHelper(self.session)
        self.enterprise = EnterpriseHelper(self.session)
        self.factors = FactorHelper(self.session)
        self.group_members = GroupMemberHelper(self.session)
        self.groups = GroupHelper(self.session)
        self.levels = LevelHelper(self.session)
        self.response_options = ResponseOptionHelper(self.session)
        self.responses = ResponseHelper(self.session)
        self.rules = RulesHelper(self.session)
        self.statistics = StatisticsHelper(self.session)
        self.themes = ThemeHelper(self.session)
        self.users = UserHelper(self.session, name, token)

        Logger.display = ConfigHelper.verbose

    def __enter__(self):
        _, r = self.users.login()
        if r.status_code == 200:
            return self

        if not self.force_create:
            return None

        _, r = self.users.post_user()

        if r.status_code == 200:
            self.users.login()
            return self

        return None

    def __exit__(self, *args, **kwargs):
        self.users.logout()

    # @property
    # def user_id(self):
    #     _, r = self.users.login()
    #     if r.status_code == 200:
    #         id = json.loads(r.content.decode("utf-8"))["id"]
    #         r = self.users.logout()
    #         return id

    #     _, r = self.users.post_user()
    #     if r.status_code == 200:
    #         id = json.loads(r.content.decode("utf-8"))["id"]
    #         return id

    #     return None

    @classmethod
    def prepare_users(cls, group_name: str, users: list[str]):
        id_list = []
        for name in users:
            with SoozAccess(name, name) as user:
                id_list.append(user.users.user_id)

        # create group invitations from admin account
        with SoozAccess("admin_dev", "admin_dev") as admin:
            admin.groups.remove_groups()

            content, _ = admin.groups.post_group(group_name, "")
            group_id = content["groupId"]
            admin.group_members.post_group_invite(group_id, id_list)

        # accepts invitations from admin
        for name in users:
            with SoozAccess(name, name) as user:
                user.group_members.put_group_invitation(group_id)



import json
from typing import Tuple

from requests import Response, Session
from requests.exceptions import HTTPError

from .config_helper import ConfigHelper


class ResponseOptionHelper:
    def __init__(self, session: Session):
        self.session = session

    def get_oneshot(self) -> Tuple[dict, Response]:
        """Gets the whole survey catalogue (themes, factors, responseOptions) of an enterprise."""
        content = {}
        try:
            r = self.session.get(f"{ConfigHelper.host}/oneshot")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    One Shot", r)

        return content, r

    def get_factor_response_options(
        self, theme: int, factor: int
    ) -> Tuple[dict, Response]:
        """Get all possible responses for a particular factor."""

        content = {}

        try:
            r = self.session.get(
                f"{ConfigHelper.host}/themes/{theme}/factors/{factor}/responseOptions"
            )
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Factor Response Options", r)

        return content, r

    def get_theme_response_options(self, theme: int) -> Tuple[dict, Response]:
        """Get the responseOptions to the quetsion of a theme."""

        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/themes/{theme}/responseOptions")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Theme Response Options", r)

        return content, r



import json
from typing import Tuple

from requests import Response, Session
from requests.exceptions import HTTPError

from .config_helper import ConfigHelper


class EnterpriseHelper:
    def __init__(self, session: Session):
        self.session = session

    def get_enterprises(self) -> Tuple[dict, Response]:
        """Get all enterprises."""

        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/enterprises")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Enterprises", r)

        return content, r

    def post_enterprise(self, name: str) -> Tuple[dict, Response]:
        """Create an enterprise."""

        content = {"name": name}

        try:
            r = self.session.post(f"{ConfigHelper.host}/enterprises", json=content)
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Post Enterprise", r)

        return content, r

    def get_enterprise(self, id: int) -> Tuple[dict, Response]:
        """Get a specific enterprise."""

        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/enterprises/{id}")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Enterprise", r)

        return content, r

    def put_enterprise(self, id: int, name: str) -> Tuple[dict, Response]:
        """Update an enterprise."""

        content = {"name": name}

        try:
            r = self.session.put(f"{ConfigHelper.host}/enterprises/{id}", json=content)
            r.raise_for_status()
        except HTTPError as e:
            pass
        finally:
            ConfigHelper.show_status("    Put Enterprise", r)

        return {}, r

    def delete_enterprise(self, id: int) -> Tuple[dict, Response]:
        """Delete an enterprise."""

        try:
            r = self.session.delete(f"{ConfigHelper.host}/enterprises/{id}")
            r.raise_for_status()
        except HTTPError as e:
            pass
        finally:
            ConfigHelper.show_status("    Delete Enterprise", r)

        return {}, r

    def get_enterprise_users(self, id: int) -> Tuple[dict, Response]:
        """Get the users of an enterprise if the user is part of the enterprise"""

        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/enterprises/{id}/users")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Enterprise Users", r)

        return content, r

    def get_enterprise_rooms(self, id: int) -> Tuple[dict, Response]:
        """Get all rooms for an entreprise (needs to be an admin user)."""

        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/enterprises/{id}/rooms")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Enterprise Rooms", r)

        return content, r

    def get_enterprise_factors(self, enterprise: int) -> Tuple[dict, Response]:
        """Get all factors with selected factors of an enterprise."""

        content = {}

        try:
            r = self.session.get(
                f"{ConfigHelper.host}/enterprises/{enterprise}/factors"
            )
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Enterprise Factors", r)

        return content, r

    def put_entreprise_factors(self, enterprise: int) -> Tuple[dict, Response]:
        """Purge and recreate selected factors of an enterprise."""
        raise NotImplementedError("Not implemented yet")



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="spoton_soozaccess",
    version="0.3.3",
    author="Jean Demeusy",
    author_email="dev.jdu@gmail.com",
    description="A tool to access Spot-On API using Python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitlab.forge.hefr.ch/pa-spot-on-demeusy/spot-on-soozaccess",
    packages=["spoton_soozaccess"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=["click", "requests"],
)



import json
from typing import Tuple

from requests import Response, Session
from requests.exceptions import HTTPError

from .config_helper import ConfigHelper


class RulesHelper:
    def __init__(self, session: Session):
        self.session = session

    def get_rules(self) -> Tuple[dict, Response]:
        """Get all rules"""
        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/rules")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Get Rules", r)

        return content, r

    def post_rule(
        self,
        periodicity: str,
        operator: str,
        participation_rate: float,
        voting_rate: float,
        vote_type: str,
        rate: float,
        prefix: str,
        name: str,
        factor_id: int,
        group_id: int,
        user_id: int,
    ) -> Tuple[dict, Response]:
        """Post a rule"""

        content = {
            "periodicity": periodicity,
            "operator": operator,
            "participationRate": participation_rate,
            "votingRate": voting_rate,
            "voteType": vote_type,
            "rate": rate,
            "messagePrefix": prefix,
            "name": name,
            "factorId": factor_id,
            "groupId": group_id,
            "personId": user_id,
        }

        try:
            r = self.session.post(f"{ConfigHelper.host}/rules", json=content)
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Post Rule", r)

        return content, r

    def put_rule(self, id: int):
        """Archives a rule"""

        try:
            r = self.session.put(f"{ConfigHelper.host}/rules/{id}")
            r.raise_for_status()
        except HTTPError as e:
            pass
        finally:
            ConfigHelper.show_status("    Put Group", r)

        return {}, r

    def delete_rule(self, id: int):
        """Deletes a rule"""

        try:
            r = self.session.delete(f"{ConfigHelper.host}/rules/{id}")
            r.raise_for_status()
        except HTTPError as e:
            pass
        finally:
            ConfigHelper.show_status("    Delete Rule", r)

        return {}, r



import json
from typing import Tuple
from requests import Response, Session
from requests.exceptions import HTTPError

from .config_helper import ConfigHelper


class FactorHelper:
    def __init__(self, session: Session):
        self.session = session

    def get_factors(self, theme: int) -> Tuple[dict, Response]:
        """Get all factors for a theme (not specific to an enterprise)."""
        content = {}

        try:
            r = self.session.get(f"{ConfigHelper.host}/themes/{theme}/factors")
            r.raise_for_status()
        except HTTPError as e:
            pass
        else:
            content = json.loads(r.content.decode("utf-8"))
        finally:
            ConfigHelper.show_status("    Factor", r)

        return content, r
